class UWSDatabaseRouter:
    """
    A router to control all database operations on models in the
    UWS application.

    Can be used to optionally use a different database for the UWS app.
    """

    route_app_labels = {"uws"}

    def db_for_read(self, model, **hints):
        """
        Attempts to read auth and contenttypes models go to uws.
        """
        if model._meta.app_label in self.route_app_labels:
            return "uws"
        return None

    def db_for_write(self, model, **hints):
        """
        Attempts to write auth and contenttypes models go to uws.
        """
        if model._meta.app_label in self.route_app_labels:
            return "uws"
        return None

    def allow_relation(self, obj1, obj2, **hints):
        """
        Allow relations if a model in the auth or contenttypes apps is
        involved.
        """
        if (
            obj1._meta.app_label in self.route_app_labels
            or obj2._meta.app_label in self.route_app_labels
        ):
            return True
        return None

    def allow_migrate(self, db, app_label, model_name=None, **hints):
        """
        Make sure the uws apps only appear in the
        'uws' database.
        """
        if app_label in self.route_app_labels:
            return db == "uws"
        return None
